@@ -17,31 +17,31 @@ from decimal import Decimal
 from typing import Any, Dict, List, Set, Union
 
 from .literals import (
-    AttributeAction,
-    BackupStatus,
-    BackupType,
-    BatchStatementErrorCodeEnum,
-    BillingMode,
-    ComparisonOperator,
-    ContinuousBackupsStatus,
-    ContributorInsightsStatus,
-    DestinationStatus,
-    ExportFormat,
-    ExportStatus,
-    GlobalTableStatus,
-    IndexStatus,
-    KeyType,
-    PointInTimeRecoveryStatus,
-    ProjectionType,
-    ReplicaStatus,
-    ReturnValuesOnConditionCheckFailure,
-    S3SseAlgorithm,
-    ScalarAttributeType,
-    SSEStatus,
-    SSEType,
-    StreamViewType,
-    TableStatus,
-    TimeToLiveStatus,
+    AttributeActionType,
+    BackupStatusType,
+    BackupTypeType,
+    BatchStatementErrorCodeEnumType,
+    BillingModeType,
+    ComparisonOperatorType,
+    ContinuousBackupsStatusType,
+    ContributorInsightsStatusType,
+    DestinationStatusType,
+    ExportFormatType,
+    ExportStatusType,
+    GlobalTableStatusType,
+    IndexStatusType,
+    KeyTypeType,
+    PointInTimeRecoveryStatusType,
+    ProjectionTypeType,
+    ReplicaStatusType,
+    ReturnValuesOnConditionCheckFailureType,
+    S3SseAlgorithmType,
+    ScalarAttributeTypeType,
+    SSEStatusType,
+    SSETypeType,
+    StreamViewTypeType,
+    TableStatusType,
+    TimeToLiveStatusType,
 )
 
 if sys.version_info >= (3, 8):
@@ -209,7 +209,7 @@ AttributeDefinitionTypeDef = TypedDict(
     "AttributeDefinitionTypeDef",
     {
         "AttributeName": str,
-        "AttributeType": ScalarAttributeType,
+        "AttributeType": ScalarAttributeTypeType,
     },
 )
 
@@ -232,7 +232,7 @@ AttributeValueUpdateTypeDef = TypedDict(
             Dict[str, Any],
             None,
         ],
-        "Action": AttributeAction,
+        "Action": AttributeActionType,
     },
     total=False,
 )
@@ -354,8 +354,8 @@ _RequiredBackupDetailsTypeDef = TypedDict(
     {
         "BackupArn": str,
         "BackupName": str,
-        "BackupStatus": BackupStatus,
-        "BackupType": BackupType,
+        "BackupStatus": BackupStatusType,
+        "BackupType": BackupTypeType,
         "BackupCreationDateTime": datetime,
     },
 )
@@ -383,8 +383,8 @@ BackupSummaryTypeDef = TypedDict(
         "BackupName": str,
         "BackupCreationDateTime": datetime,
         "BackupExpiryDateTime": datetime,
-        "BackupStatus": BackupStatus,
-        "BackupType": BackupType,
+        "BackupStatus": BackupStatusType,
+        "BackupType": BackupTypeType,
         "BackupSizeBytes": int,
     },
     total=False,
@@ -434,7 +434,7 @@ BatchGetItemOutputTypeDef = TypedDict(
 BatchStatementErrorTypeDef = TypedDict(
     "BatchStatementErrorTypeDef",
     {
-        "Code": BatchStatementErrorCodeEnum,
+        "Code": BatchStatementErrorCodeEnumType,
         "Message": str,
     },
     total=False,
@@ -520,7 +520,7 @@ BatchWriteItemOutputTypeDef = TypedDict(
 BillingModeSummaryTypeDef = TypedDict(
     "BillingModeSummaryTypeDef",
     {
-        "BillingMode": BillingMode,
+        "BillingMode": BillingModeType,
         "LastUpdateToPayPerRequestDateTime": datetime,
     },
     total=False,
@@ -585,7 +585,7 @@ _OptionalConditionCheckTypeDef = TypedDict(
                 None,
             ],
         ],
-        "ReturnValuesOnConditionCheckFailure": ReturnValuesOnConditionCheckFailure,
+        "ReturnValuesOnConditionCheckFailure": ReturnValuesOnConditionCheckFailureType,
     },
     total=False,
 )
@@ -598,7 +598,7 @@ class ConditionCheckTypeDef(_RequiredConditionCheckTypeDef, _OptionalConditionCh
 _RequiredConditionTypeDef = TypedDict(
     "_RequiredConditionTypeDef",
     {
-        "ComparisonOperator": ComparisonOperator,
+        "ComparisonOperator": ComparisonOperatorType,
     },
 )
 _OptionalConditionTypeDef = TypedDict(
@@ -648,7 +648,7 @@ ConsumedCapacityTypeDef = TypedDict(
 _RequiredContinuousBackupsDescriptionTypeDef = TypedDict(
     "_RequiredContinuousBackupsDescriptionTypeDef",
     {
-        "ContinuousBackupsStatus": ContinuousBackupsStatus,
+        "ContinuousBackupsStatus": ContinuousBackupsStatusType,
     },
 )
 _OptionalContinuousBackupsDescriptionTypeDef = TypedDict(
@@ -671,7 +671,7 @@ ContributorInsightsSummaryTypeDef = TypedDict(
     {
         "TableName": str,
         "IndexName": str,
-        "ContributorInsightsStatus": ContributorInsightsStatus,
+        "ContributorInsightsStatus": ContributorInsightsStatusType,
     },
     total=False,
 )
@@ -894,7 +894,7 @@ _OptionalDeleteTypeDef = TypedDict(
                 None,
             ],
         ],
-        "ReturnValuesOnConditionCheckFailure": ReturnValuesOnConditionCheckFailure,
+        "ReturnValuesOnConditionCheckFailure": ReturnValuesOnConditionCheckFailureType,
     },
     total=False,
 )
@@ -926,7 +926,7 @@ DescribeContributorInsightsOutputTypeDef = TypedDict(
         "TableName": str,
         "IndexName": str,
         "ContributorInsightsRuleList": List[str],
-        "ContributorInsightsStatus": ContributorInsightsStatus,
+        "ContributorInsightsStatus": ContributorInsightsStatusType,
         "LastUpdateDateTime": datetime,
         "FailureException": "FailureExceptionTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -1074,7 +1074,7 @@ ExpectedAttributeValueTypeDef = TypedDict(
             None,
         ],
         "Exists": bool,
-        "ComparisonOperator": ComparisonOperator,
+        "ComparisonOperator": ComparisonOperatorType,
         "AttributeValueList": List[
             Union[
                 bytes,
@@ -1101,7 +1101,7 @@ ExportDescriptionTypeDef = TypedDict(
     "ExportDescriptionTypeDef",
     {
         "ExportArn": str,
-        "ExportStatus": ExportStatus,
+        "ExportStatus": ExportStatusType,
         "StartTime": datetime,
         "EndTime": datetime,
         "ExportManifest": str,
@@ -1112,11 +1112,11 @@ ExportDescriptionTypeDef = TypedDict(
         "S3Bucket": str,
         "S3BucketOwner": str,
         "S3Prefix": str,
-        "S3SseAlgorithm": S3SseAlgorithm,
+        "S3SseAlgorithm": S3SseAlgorithmType,
         "S3SseKmsKeyId": str,
         "FailureCode": str,
         "FailureMessage": str,
-        "ExportFormat": ExportFormat,
+        "ExportFormat": ExportFormatType,
         "BilledSizeBytes": int,
         "ItemCount": int,
     },
@@ -1127,7 +1127,7 @@ ExportSummaryTypeDef = TypedDict(
     "ExportSummaryTypeDef",
     {
         "ExportArn": str,
-        "ExportStatus": ExportStatus,
+        "ExportStatus": ExportStatusType,
     },
     total=False,
 )
@@ -1230,7 +1230,7 @@ GlobalSecondaryIndexDescriptionTypeDef = TypedDict(
         "IndexName": str,
         "KeySchema": List["KeySchemaElementTypeDef"],
         "Projection": "ProjectionTypeDef",
-        "IndexStatus": IndexStatus,
+        "IndexStatus": IndexStatusType,
         "Backfilling": bool,
         "ProvisionedThroughput": "ProvisionedThroughputDescriptionTypeDef",
         "IndexSizeBytes": int,
@@ -1290,7 +1290,7 @@ GlobalTableDescriptionTypeDef = TypedDict(
         "ReplicationGroup": List["ReplicaDescriptionTypeDef"],
         "GlobalTableArn": str,
         "CreationDateTime": datetime,
-        "GlobalTableStatus": GlobalTableStatus,
+        "GlobalTableStatus": GlobalTableStatusType,
         "GlobalTableName": str,
     },
     total=False,
@@ -1385,7 +1385,7 @@ KeySchemaElementTypeDef = TypedDict(
     "KeySchemaElementTypeDef",
     {
         "AttributeName": str,
-        "KeyType": KeyType,
+        "KeyType": KeyTypeType,
     },
 )
 
@@ -1437,7 +1437,7 @@ KinesisDataStreamDestinationTypeDef = TypedDict(
     "KinesisDataStreamDestinationTypeDef",
     {
         "StreamArn": str,
-        "DestinationStatus": DestinationStatus,
+        "DestinationStatus": DestinationStatusType,
         "DestinationStatusDescription": str,
     },
     total=False,
@@ -1448,7 +1448,7 @@ KinesisStreamingDestinationOutputTypeDef = TypedDict(
     {
         "TableName": str,
         "StreamArn": str,
-        "DestinationStatus": DestinationStatus,
+        "DestinationStatus": DestinationStatusType,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -1590,7 +1590,7 @@ class ParameterizedStatementTypeDef(
 PointInTimeRecoveryDescriptionTypeDef = TypedDict(
     "PointInTimeRecoveryDescriptionTypeDef",
     {
-        "PointInTimeRecoveryStatus": PointInTimeRecoveryStatus,
+        "PointInTimeRecoveryStatus": PointInTimeRecoveryStatusType,
         "EarliestRestorableDateTime": datetime,
         "LatestRestorableDateTime": datetime,
     },
@@ -1607,7 +1607,7 @@ PointInTimeRecoverySpecificationTypeDef = TypedDict(
 ProjectionTypeDef = TypedDict(
     "ProjectionTypeDef",
     {
-        "ProjectionType": ProjectionType,
+        "ProjectionType": ProjectionTypeType,
         "NonKeyAttributes": List[str],
     },
     total=False,
@@ -1743,7 +1743,7 @@ _OptionalPutTypeDef = TypedDict(
                 None,
             ],
         ],
-        "ReturnValuesOnConditionCheckFailure": ReturnValuesOnConditionCheckFailure,
+        "ReturnValuesOnConditionCheckFailure": ReturnValuesOnConditionCheckFailureType,
     },
     total=False,
 )
@@ -1810,7 +1810,7 @@ ReplicaAutoScalingDescriptionTypeDef = TypedDict(
         "GlobalSecondaryIndexes": List["ReplicaGlobalSecondaryIndexAutoScalingDescriptionTypeDef"],
         "ReplicaProvisionedReadCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
         "ReplicaProvisionedWriteCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
-        "ReplicaStatus": ReplicaStatus,
+        "ReplicaStatus": ReplicaStatusType,
     },
     total=False,
 )
@@ -1843,7 +1843,7 @@ ReplicaDescriptionTypeDef = TypedDict(
     "ReplicaDescriptionTypeDef",
     {
         "RegionName": str,
-        "ReplicaStatus": ReplicaStatus,
+        "ReplicaStatus": ReplicaStatusType,
         "ReplicaStatusDescription": str,
         "ReplicaStatusPercentProgress": str,
         "KMSMasterKeyId": str,
@@ -1858,7 +1858,7 @@ ReplicaGlobalSecondaryIndexAutoScalingDescriptionTypeDef = TypedDict(
     "ReplicaGlobalSecondaryIndexAutoScalingDescriptionTypeDef",
     {
         "IndexName": str,
-        "IndexStatus": IndexStatus,
+        "IndexStatus": IndexStatusType,
         "ProvisionedReadCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
         "ProvisionedWriteCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
     },
@@ -1892,7 +1892,7 @@ _RequiredReplicaGlobalSecondaryIndexSettingsDescriptionTypeDef = TypedDict(
 _OptionalReplicaGlobalSecondaryIndexSettingsDescriptionTypeDef = TypedDict(
     "_OptionalReplicaGlobalSecondaryIndexSettingsDescriptionTypeDef",
     {
-        "IndexStatus": IndexStatus,
+        "IndexStatus": IndexStatusType,
         "ProvisionedReadCapacityUnits": int,
         "ProvisionedReadCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
         "ProvisionedWriteCapacityUnits": int,
@@ -1962,7 +1962,7 @@ _RequiredReplicaSettingsDescriptionTypeDef = TypedDict(
 _OptionalReplicaSettingsDescriptionTypeDef = TypedDict(
     "_OptionalReplicaSettingsDescriptionTypeDef",
     {
-        "ReplicaStatus": ReplicaStatus,
+        "ReplicaStatus": ReplicaStatusType,
         "ReplicaBillingModeSummary": "BillingModeSummaryTypeDef",
         "ReplicaProvisionedReadCapacityUnits": int,
         "ReplicaProvisionedReadCapacityAutoScalingSettings": "AutoScalingSettingsDescriptionTypeDef",
@@ -2085,8 +2085,8 @@ RestoreTableToPointInTimeOutputTypeDef = TypedDict(
 SSEDescriptionTypeDef = TypedDict(
     "SSEDescriptionTypeDef",
     {
-        "Status": SSEStatus,
-        "SSEType": SSEType,
+        "Status": SSEStatusType,
+        "SSEType": SSETypeType,
         "KMSMasterKeyArn": str,
         "InaccessibleEncryptionDateTime": datetime,
     },
@@ -2097,7 +2097,7 @@ SSESpecificationTypeDef = TypedDict(
     "SSESpecificationTypeDef",
     {
         "Enabled": bool,
-        "SSEType": SSEType,
+        "SSEType": SSETypeType,
         "KMSMasterKeyId": str,
     },
     total=False,
@@ -2169,7 +2169,7 @@ _OptionalSourceTableDetailsTypeDef = TypedDict(
         "TableArn": str,
         "TableSizeBytes": int,
         "ItemCount": int,
-        "BillingMode": BillingMode,
+        "BillingMode": BillingModeType,
     },
     total=False,
 )
@@ -2202,7 +2202,7 @@ _RequiredStreamSpecificationTypeDef = TypedDict(
 _OptionalStreamSpecificationTypeDef = TypedDict(
     "_OptionalStreamSpecificationTypeDef",
     {
-        "StreamViewType": StreamViewType,
+        "StreamViewType": StreamViewTypeType,
     },
     total=False,
 )
@@ -2218,7 +2218,7 @@ TableAutoScalingDescriptionTypeDef = TypedDict(
     "TableAutoScalingDescriptionTypeDef",
     {
         "TableName": str,
-        "TableStatus": TableStatus,
+        "TableStatus": TableStatusType,
         "Replicas": List["ReplicaAutoScalingDescriptionTypeDef"],
     },
     total=False,
@@ -2230,7 +2230,7 @@ TableDescriptionTypeDef = TypedDict(
         "AttributeDefinitions": List["AttributeDefinitionTypeDef"],
         "TableName": str,
         "KeySchema": List["KeySchemaElementTypeDef"],
-        "TableStatus": TableStatus,
+        "TableStatus": TableStatusType,
         "CreationDateTime": datetime,
         "ProvisionedThroughput": "ProvisionedThroughputDescriptionTypeDef",
         "TableSizeBytes": int,
@@ -2263,7 +2263,7 @@ TagTypeDef = TypedDict(
 TimeToLiveDescriptionTypeDef = TypedDict(
     "TimeToLiveDescriptionTypeDef",
     {
-        "TimeToLiveStatus": TimeToLiveStatus,
+        "TimeToLiveStatus": TimeToLiveStatusType,
         "AttributeName": str,
     },
     total=False,
@@ -2326,7 +2326,7 @@ UpdateContributorInsightsOutputTypeDef = TypedDict(
     {
         "TableName": str,
         "IndexName": str,
-        "ContributorInsightsStatus": ContributorInsightsStatus,
+        "ContributorInsightsStatus": ContributorInsightsStatusType,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -2482,7 +2482,7 @@ _OptionalUpdateTypeDef = TypedDict(
                 None,
             ],
         ],
-        "ReturnValuesOnConditionCheckFailure": ReturnValuesOnConditionCheckFailure,
+        "ReturnValuesOnConditionCheckFailure": ReturnValuesOnConditionCheckFailureType,
     },
     total=False,
 )
